/* 
 * Command.java --
 *
 *	This file contains the Command class which encapsulates the
 *	callbacks for a Tcl command implementation.
 *
 * Copyright (c) 1995 by Sun Microsystems, Inc.
 *
 * See the file "license.terms" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 * SCCS: @(#) Command.java 1.2 95/12/19 14:34:40
 */

package tcl;

/**
 * The interface for classes which implement Tcl commands.
 * In order to create a new Tcl command, an application should implement
 * the Command interface.  Commands are registered using methods in the
 * Interp class.
 * @see Interp#createCommand
 */

public interface Command {

    /**
     * Processes a Tcl command.
     * @param interp the Tcl interpreter in which the command is executing.
     * @param args the arguments to the command.  The name by which the
     * command was invoked will be in args[0].
     * @return the command result
     * @exception Tcl_ResultCodeException signals Tcl-style exception
     * conditions, including return, break, and continue conditions in
     * addition to errors and user-defined exceptions.
     * @see Tcl_ErrorException
     * @see Tcl_UserException
     * @see Tcl_BreakException
     * @see Tcl_ContinueException
     * @see Tcl_ReturnException
     */
    public Value
    invoke(Interp interp, Value args[]) throws Tcl_ResultCodeException;

    /**
     * Special actions to be taken when the command is deleted.
     * This method is called by the Tcl interpreter when the command is
     * deleted.  If no special cleanup needs to be performed, this method
     * need not take any action.
     * @param interp the Tcl interpreter in which the command is executing.
     */
    public void
    deleted(Interp interp);
}
